# *DIRESA*


### Overview

*DIRESA* is a Python package for dimension reduction based on 
[TensorFlow](https://www.tensorflow.org). The distance-regularized 
Siamese twin autoencoder architecture is designed to preserve distance 
(ordering) in latent space while capturing the non-linearities in
the datasets.


### Prerequisites

The *DIRESA* package depends on the [tensorflow](https://www.tensorflow.org) 
and [tensorflow_probability](https://www.tensorflow.org/probability) packages. 
These can be installed with the following commands:

``` bash
  pip install tensorflow
  pip install tensorflow_probability
```

### Install *DIRESA*

Install *DIRESA* with the following command:

``` bash
  pip install diresa
```

### Documentation

The *DIRESA* documentation can be found on [Read the Docs](https://diresa-learn.readthedocs.io)